@@ -51,7 +51,6 @@
 #ifdef SELINUX_ACLS
 #include <selinux/selinux.h>
 #include <selinux/context.h>
-#include <selinux/flask.h>
 #endif
 #include "buffer.h"
 #include "common.h"
@@ -1973,7 +1972,7 @@ oddjobd_exec_method(struct oddjob_dbus_context *ctx,
 			}
 			if (security_compute_create((char *) client_secontext,
 						    helper_context,
-						    SECCLASS_PROCESS,
+						    string_to_security_class("process"),
 						    &exec_context) != 0) {
 				/* Failed to compute exec context? */
 				exec_errno = 0xfe;
@@ -2985,7 +2984,8 @@ main(int argc, char **argv)
 	globals.config = config;
 
 	/* Open a connection to the message bus. */
-	ctx = oddjob_dbus_listeners_new(options.bus);
+	check_selinux_applicable();
+	ctx = oddjob_dbus_listeners_new(options.bus, globals.selinux_enabled);
 	if (ctx == NULL) {
 		fprintf(stderr, "Error connecting to D-Bus!\n");
 		return 2;
